==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/System.Design/System.Web.UI.Design.WebControls/BaseDataListComponentEditor.cs <==

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
/**
 * Namespace:   System.Web.UI.Design.WebControls
 * Class:       BaseDataListComponentEditor
 *
 * Author:      Gaurav Vaish
 * Maintainer:  mastergaurav AT users DOT sf DOT net
 *
 * (C) Gaurav Vaish (2002)
 */

using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Web.UI.Design;
using System.Windows.Forms;
using System.Windows.Forms.Design;

namespace System.Web.UI.Design.WebControls
{
	public abstract class BaseDataListComponentEditor : WindowsFormsComponentEditor
	{
		private int initialPage;

		public BaseDataListComponentEditor(int initialPage) : base()
		{
			this.initialPage = initialPage;
		}

		public override bool EditComponent(ITypeDescriptorContext context,
		                                   object obj, IWin32Window parent)
		{
			IComponent comp = (IComponent) obj;
			ISite      site = comp.Site;
			bool retVal  = false;
			bool inTemplateMode = false;

			if(site != null)
			{
				IDesignerHost dh = (IDesignerHost)site.GetService(typeof(IDesignerHost));
				inTemplateMode = ((TemplatedControlDesigner)dh.GetDesigner(comp)).InTemplateMode;
			}
			if(inTemplateMode)
			{
				throw new NotImplementedException();
			} else
			{
				retVal = base.EditComponent(context, obj, parent);
			}
			return retVal;
		}

		protected override int GetInitialComponentEditorPageIndex()
		{
			return initialPage;
		}
	}
}

==> mono_4.6.2.7+dfsg.orig.tar.gz: mono-4.6.2+dfsg/mcs/class/System.Design/System.Web.UI.Design.WebControls/BaseDataListComponentEditor.cs <==
//
// System.Web.UI.Design.WebControls.BaseDataListComponentEditor.cs
//
// Author: Duncan Mak (duncan@novell.com)
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.ComponentModel;
using System.Windows.Forms;
using System.Windows.Forms.Design;

namespace System.Web.UI.Design.WebControls {

	public abstract class BaseDataListComponentEditor : WindowsFormsComponentEditor
	{
		int initial_page;

		public BaseDataListComponentEditor (int initial_page)
		{
			this.initial_page = initial_page;
		}

		public override bool EditComponent (
			ITypeDescriptorContext context,
			object obj,
			IWin32Window parent)
		{
			throw new NotImplementedException ();
		}

		protected override int GetInitialComponentEditorPageIndex ()
		{
			return initial_page;
		}
	}
}
